@@ -30,7 +30,7 @@ function (coordinates, path.mcmc, plotit = TRUE, format = "pdf",
         image(seq(min(coordinates[, 1] - delta.coord/2), max(coordinates[, 
             1] + delta.coord/2), length = nxdom), seq(min(coordinates[, 
             2] - delta.coord/2), max(coordinates[, 2] + delta.coord/2), 
-            length = nydom), matrix(map.dom, nr = nxdom, nc = nydom, 
+            length = nydom), matrix(map.dom, nrow = nxdom, ncol = nydom, 
             byrow = TRUE), xlab = "", ylab = "", main = "", cex = 1.5, 
             cex.lab = 1.5, col = terrain.colors(npopmax), xlim = c(min(coordinates[, 
                 1] - delta.coord/2 - frame), max(coordinates[, 
@@ -53,7 +53,7 @@ function (coordinates, path.mcmc, plotit = TRUE, format = "pdf",
         image(seq(min(coordinates[, 1] - delta.coord/2), max(coordinates[, 
             1] + delta.coord/2), length = nxdom), seq(min(coordinates[, 
             2] - delta.coord/2), max(coordinates[, 2] + delta.coord/2), 
-            length = nydom), matrix(map.dom, nr = nxdom, nc = nydom, 
+            length = nydom), matrix(map.dom, nrow = nxdom, ncol = nydom, 
             byrow = TRUE), xlab = "", ylab = "", main = "", cex = 1.5, 
             cex.lab = 1.5, col = terrain.colors(npopmax), xlim = c(min(coordinates[, 
                 1] - delta.coord/2 - frame), max(coordinates[, 
